Returns content from the Option, or reads from stdin if not a TTY.
Returns an empty string if content is None and stdin is a TTY.
Propagates I/O errors from stdin.
Returns the configured quick_note_path for the active workspace.
Falls back to VaultPath::root() for Phase 1 workspaces (no WorkspaceEntry) or if not configured.