pub fn load_settings(config_path: Option<PathBuf>) -> Result<AppSettings>Expand description
Load settings from either a specific config file path or the default location.
pub fn load_settings(config_path: Option<PathBuf>) -> Result<AppSettings>Load settings from either a specific config file path or the default location.