pub enum DrawerView {
Files,
Find,
Tags,
Links,
Outline,
Config,
}Expand description
The views the activity rail can put in the drawer. Closed set, mirrors the rail items top to bottom.
Variants
Implementations