redraw_callback

Function redraw_callback 

pub fn redraw_callback(tx: AppTx) -> Arc<dyn Fn() + Send + Sync + 'static> 
Build a Send + Sync callback that fires AppEvent::Redraw on the app event bus. Used by long-lived components (autocomplete query task, etc.) that need to wake the render loop from a background thread but should not be aware of AppEvent themselves.