pub fn global_hints(kb: &KeyBindings) -> Vec<Hint> ⓘExpand description
The always-on global hints, right-aligned on status line 1: the actions a user must always be able to find regardless of focus.
pub fn global_hints(kb: &KeyBindings) -> Vec<Hint> ⓘThe always-on global hints, right-aligned on status line 1: the actions a user must always be able to find regardless of focus.