pub struct NoteBrowserModal { /* private fields */ }Implementations
Sourceimpl NoteBrowserModal
impl NoteBrowserModal
pub fn new( title: impl Into<String>, scope: BrowserScope, provider: impl RowSource<FileListEntry>, vault: Arc<NoteVault>, key_bindings: KeyBindings, icons: Icons, tx: AppTx, ) -> Self
Sourcepub fn with_initial_query<S: Into<String>>(
title: impl Into<String>,
scope: BrowserScope,
provider: impl RowSource<FileListEntry>,
vault: Arc<NoteVault>,
key_bindings: KeyBindings,
icons: Icons,
tx: AppTx,
query: S,
) -> Self
pub fn with_initial_query<S: Into<String>>( title: impl Into<String>, scope: BrowserScope, provider: impl RowSource<FileListEntry>, vault: Arc<NoteVault>, key_bindings: KeyBindings, icons: Icons, tx: AppTx, query: S, ) -> Self
Construct the modal with a pre-filled search query.
Behaves exactly like new except the search input is
pre-populated with query (cursor placed at the end) and the initial
load is triggered for that query string.
Sourcepub fn with_row_sort(self) -> Self
pub fn with_row_sort(self) -> Self
Make a Files-scope list sortable from the sort dialog (the Ctrl+O finder): rows re-sort by name, title or a property’s indexed value. A no-op for the Query scope, which sorts through its query.