pub enum KeyStrike {
Show 102 variants
None,
Unknown,
Backquote,
Backslash,
BracketLeft,
BracketRight,
Comma,
Digit0,
Digit1,
Digit2,
Digit3,
Digit4,
Digit5,
Digit6,
Digit7,
Digit8,
Digit9,
Equal,
KeyA,
KeyB,
KeyC,
KeyD,
KeyE,
KeyF,
KeyG,
KeyH,
KeyI,
KeyJ,
KeyK,
KeyL,
KeyM,
KeyN,
KeyO,
KeyP,
KeyQ,
KeyR,
KeyS,
KeyT,
KeyU,
KeyV,
KeyW,
KeyX,
KeyY,
KeyZ,
Minus,
Period,
Quote,
Semicolon,
Slash,
Backspace,
Enter,
Space,
Tab,
Delete,
End,
Home,
Insert,
PageDown,
PageUp,
ArrowDown,
ArrowLeft,
ArrowRight,
ArrowUp,
Escape,
PrintScreen,
ScrollLock,
Pause,
F1,
F2,
F3,
F4,
F5,
F6,
F7,
F8,
F9,
F10,
F11,
F12,
F13,
F14,
F15,
F16,
F17,
F18,
F19,
F20,
F21,
F22,
F23,
F24,
F25,
F26,
F27,
F28,
F29,
F30,
F31,
F32,
F33,
F34,
F35,
}Variants
None
Unknown
Backquote
`~ on a US keyboard. This is the 半角/全角/漢字 (hankaku/zenkaku/kanji) key on Japanese keyboards
Backslash
Used for both the US | (on the 101-key layout) and also for the key
located between the “ and Enter keys on row C of the 102-,
104- and 106-key layouts.
Labelled #~ on a UK (102) keyboard.
BracketLeft
[{ on a US keyboard.
BracketRight
]} on a US keyboard.
Comma
,< on a US keyboard.
Digit0
0) on a US keyboard.
Digit1
1! on a US keyboard.
Digit2
2@ on a US keyboard.
Digit3
3# on a US keyboard.
Digit4
4$ on a US keyboard.
Digit5
5% on a US keyboard.
Digit6
6^ on a US keyboard.
Digit7
7& on a US keyboard.
Digit8
8* on a US keyboard.
Digit9
9( on a US keyboard.
Equal
=+ on a US keyboard.
KeyA
Located between the left Shift and Z keys.
Labelled | on a UK keyboard.
KeyB
b on a US keyboard.
KeyC
c on a US keyboard.
KeyD
d on a US keyboard.
KeyE
e on a US keyboard.
KeyF
f on a US keyboard.
KeyG
g on a US keyboard.
KeyH
h on a US keyboard.
KeyI
i on a US keyboard.
KeyJ
j on a US keyboard.
KeyK
k on a US keyboard.
KeyL
l on a US keyboard.
KeyM
m on a US keyboard.
KeyN
n on a US keyboard.
KeyO
o on a US keyboard.
KeyP
p on a US keyboard.
KeyQ
q on a US keyboard.
Labelled a on an AZERTY (e.g., French) keyboard.
KeyR
r on a US keyboard.
KeyS
s on a US keyboard.
KeyT
t on a US keyboard.
KeyU
u on a US keyboard.
KeyV
v on a US keyboard.
KeyW
w on a US keyboard.
Labelled z on an AZERTY (e.g., French) keyboard.
KeyX
x on a US keyboard.
KeyY
y on a US keyboard.
Labelled z on a QWERTZ (e.g., German) keyboard.
KeyZ
z on a US keyboard.
Labelled w on an AZERTY (e.g., French) keyboard, and y on a
QWERTZ (e.g., German) keyboard.
Minus
-_ on a US keyboard.
Period
.> on a US keyboard.
Quote
’“ on a US keyboard.
Semicolon
;: on a US keyboard.
Slash
/? on a US keyboard.
Backspace
Backspace or ⌫.
Labelled Delete on Apple keyboards.
Enter
CapsLock or ⇪
Space
(space)
Tab
Tab or ⇥
Delete
End
End or ↘
Home
Home or ↖
Insert
Insert or Ins. Not present on Apple keyboards.
PageDown
Page Down, PgDn or ⇟
PageUp
Page Up, PgUp or ⇞
ArrowDown
↓
ArrowLeft
←
ArrowRight
→
ArrowUp
↑
Escape
Esc or ⎋
PrintScreen
PrtScr SysRq or Print Screen
ScrollLock
Scroll Lock
Pause
Pause Break
F1
Some laptops place this key to the left of the ↑ key.
F1
F2
F2
F3
F3
F4
F4
F5
F5
F6
F6
F7
F7
F8
F8
F9
F9
F10
F10
F11
F11
F12
F12
F13
F13
F14
F14
F15
F15
F16
F16
F17
F17
F18
F18
F19
F19
F20
F20
F21
F21
F22
F22
F23
F23
F24
F24
F25
F25
F26
F26
F27
F27
F28
F28
F29
F29
F30
F30
F31
F31
F32
F32
F33
F33
F34
F34
F35
F35