pub async fn install(latest: LatestRelease) -> Result<(), UpdateError>Expand description
Async apply — consumes latest so it can move onto the blocking pool.
pub async fn install(latest: LatestRelease) -> Result<(), UpdateError>Async apply — consumes latest so it can move onto the blocking pool.