pub fn config_dir() -> Result<PathBuf, SystemError>Expand description
Path to kimün’s directory on this machine, creating it if needed — used by
the update module for the install marker and update-state file. The layout
(and the debug/release name) belongs to kimun_core::system.