pub struct WorkspaceEntry {
pub path: PathBuf,
pub last_paths: Vec<String>,
pub created: DateTime<Utc>,
pub quick_note_path: Option<String>,
pub inbox_path: Option<String>,
pub resolved_path: Option<PathBuf>,
}Fields
path: PathBuflast_paths: Vec<String>created: DateTime<Utc>quick_note_path: Option<String>inbox_path: Option<String>resolved_path: Option<PathBuf>Absolute resolved path for runtime use. Not serialized — path is
written to disk as the user configured it (relative, ~/…, or absolute).
Implementations
Sourceimpl WorkspaceEntry
impl WorkspaceEntry
Sourcepub fn effective_path(&self) -> &PathBuf
pub fn effective_path(&self) -> &PathBuf
Returns the resolved absolute path if available, otherwise the original path.
pub fn effective_quick_note_path(&self) -> String
pub fn effective_inbox_path(&self) -> String